# howso-openapi-client
OpenAPI implementation for interacting with the Howso API.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 26.5.0
- Package version: 24.0.8
- Build package: org.openapitools.codegen.languages.PythonLegacyClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import howso.openapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import howso.openapi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import howso.openapi
from howso.openapi.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost/api/v2
# See configuration.py for a list of all supported configuration parameters.
configuration = howso.openapi.Configuration(
    host = "https://localhost/api/v2"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: oauth_ums
configuration = howso.openapi.Configuration(
    host = "https://localhost/api/v2"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'


# Enter a context with an instance of the API client
with howso.openapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = howso.openapi.AccountApi(api_client)

    try:
        # Get your account details.
        api_response = api_instance.me()
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountApi->me: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/api/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**me**](docs/AccountApi.md#me) | **GET** /manage/accounts/me/ | Get your account details.
*InformationApi* | [**get_trainee_information**](docs/InformationApi.md#get_trainee_information) | **GET** /trainee/{trainee_id}/info | Trainee information
*InformationApi* | [**get_version**](docs/InformationApi.md#get_version) | **GET** /version |
*ProjectManagementApi* | [**create_project**](docs/ProjectManagementApi.md#create_project) | **POST** /manage/projects/ | Create a project.
*ProjectManagementApi* | [**delete_project**](docs/ProjectManagementApi.md#delete_project) | **DELETE** /manage/projects/{project_id}/ | Delete a project.
*ProjectManagementApi* | [**get_project**](docs/ProjectManagementApi.md#get_project) | **GET** /manage/projects/{project_id}/ | Get a project&#39;s details.
*ProjectManagementApi* | [**list_projects**](docs/ProjectManagementApi.md#list_projects) | **GET** /manage/projects/ | List your projects.
*ProjectManagementApi* | [**update_project**](docs/ProjectManagementApi.md#update_project) | **PUT** /manage/projects/{project_id}/ | Update a project.
*SessionManagementApi* | [**begin_session**](docs/SessionManagementApi.md#begin_session) | **POST** /session | Start a new session.
*SessionManagementApi* | [**get_active_session**](docs/SessionManagementApi.md#get_active_session) | **GET** /session | Get active session.
*SessionManagementApi* | [**get_session**](docs/SessionManagementApi.md#get_session) | **GET** /manage/sessions/{session_id}/ | Get a session&#39;s details.
*SessionManagementApi* | [**list_sessions**](docs/SessionManagementApi.md#list_sessions) | **GET** /manage/sessions/ | List your sessions.
*SessionManagementApi* | [**update_session**](docs/SessionManagementApi.md#update_session) | **PUT** /manage/sessions/{session_id}/ | Update a session.
*TaskOperationsApi* | [**cancel_action**](docs/TaskOperationsApi.md#cancel_action) | **PUT** /operations/actions/{action_id}/cancel | Cancel an async action
*TaskOperationsApi* | [**get_action**](docs/TaskOperationsApi.md#get_action) | **GET** /operations/actions/{action_id} | Status of an async action
*TaskOperationsApi* | [**get_action_output**](docs/TaskOperationsApi.md#get_action_output) | **GET** /operations/actions/{action_id}/output | Output of an async action
*TaskOperationsApi* | [**list_pending_actions**](docs/TaskOperationsApi.md#list_pending_actions) | **GET** /operations/actions | List pending async actions.
*TaskOperationsApi* | [**list_pending_trainee_actions**](docs/TaskOperationsApi.md#list_pending_trainee_actions) | **GET** /trainee/{trainee_id}/actions | List pending trainee async actions.
*TraineeCaseOperationsApi* | [**edit_cases**](docs/TraineeCaseOperationsApi.md#edit_cases) | **POST** /trainee/{trainee_id}/cases/edit | Edit one or more cases in a trainee.
*TraineeCaseOperationsApi* | [**get_cases**](docs/TraineeCaseOperationsApi.md#get_cases) | **POST** /trainee/{trainee_id}/cases | Get case data from a trainee
*TraineeCaseOperationsApi* | [**get_num_training_cases**](docs/TraineeCaseOperationsApi.md#get_num_training_cases) | **GET** /trainee/{trainee_id}/cases/count | Get the number of cases for a trainee
*TraineeCaseOperationsApi* | [**remove_cases**](docs/TraineeCaseOperationsApi.md#remove_cases) | **POST** /trainee/{trainee_id}/cases/remove | Remove one or more cases from a trainee
*TraineeDefaultsManagementApi* | [**get_user_feature_defaults**](docs/TraineeDefaultsManagementApi.md#get_user_feature_defaults) | **GET** /trainee/{trainee_id}/default/features | Retrieves user default action and context features for a given trainee.
*TraineeDefaultsManagementApi* | [**set_user_feature_defaults**](docs/TraineeDefaultsManagementApi.md#set_user_feature_defaults) | **POST** /trainee/{trainee_id}/default/features | Set user&#39;s default action and context features.
*TraineeFeatureOperationsApi* | [**add_feature**](docs/TraineeFeatureOperationsApi.md#add_feature) | **POST** /trainee/{trainee_id}/feature/add | Add a feature to a trainee.
*TraineeFeatureOperationsApi* | [**get_extreme_cases**](docs/TraineeFeatureOperationsApi.md#get_extreme_cases) | **POST** /trainee/{trainee_id}/cases/extreme | Get extreme top or bottom cases for specified feature(s) from a trainee
*TraineeFeatureOperationsApi* | [**get_feature_attributes**](docs/TraineeFeatureOperationsApi.md#get_feature_attributes) | **GET** /trainee/{trainee_id}/feature/attributes | Get trainee feature attributes
*TraineeFeatureOperationsApi* | [**get_feature_contributions**](docs/TraineeFeatureOperationsApi.md#get_feature_contributions) | **POST** /trainee/{trainee_id}/feature/contributions | Get contributions of features
*TraineeFeatureOperationsApi* | [**get_feature_conviction**](docs/TraineeFeatureOperationsApi.md#get_feature_conviction) | **POST** /trainee/{trainee_id}/feature/conviction | Retrieve conviction for features in the model.
*TraineeFeatureOperationsApi* | [**get_feature_residuals**](docs/TraineeFeatureOperationsApi.md#get_feature_residuals) | **POST** /trainee/{trainee_id}/feature/residuals | Get residuals of features
*TraineeFeatureOperationsApi* | [**get_marginal_stats**](docs/TraineeFeatureOperationsApi.md#get_marginal_stats) | **POST** /trainee/{trainee_id}/feature/stats/marginal | Get marginal stats for features
*TraineeFeatureOperationsApi* | [**get_prediction_stats**](docs/TraineeFeatureOperationsApi.md#get_prediction_stats) | **POST** /trainee/{trainee_id}/feature/stats/prediction | Get prediction stats for features
*TraineeFeatureOperationsApi* | [**get_substitution_map**](docs/TraineeFeatureOperationsApi.md#get_substitution_map) | **GET** /trainee/{trainee_id}/substitution-map |
*TraineeFeatureOperationsApi* | [**remove_feature**](docs/TraineeFeatureOperationsApi.md#remove_feature) | **POST** /trainee/{trainee_id}/feature/remove | Remove a feature from a trainee.
*TraineeFeatureOperationsApi* | [**set_feature_attributes**](docs/TraineeFeatureOperationsApi.md#set_feature_attributes) | **POST** /trainee/{trainee_id}/feature/attributes | Set all trainee feature attributes
*TraineeFeatureOperationsApi* | [**set_substitution_map**](docs/TraineeFeatureOperationsApi.md#set_substitution_map) | **PUT** /trainee/{trainee_id}/substitution-map |
*TraineeManagementApi* | [**acquire_trainee_resources**](docs/TraineeManagementApi.md#acquire_trainee_resources) | **POST** /trainee/{trainee_id}/resources/acquire | Acquire Trainee resources
*TraineeManagementApi* | [**copy_trainee**](docs/TraineeManagementApi.md#copy_trainee) | **POST** /trainee/{trainee_id}/copy | Copy Trainee
*TraineeManagementApi* | [**create_trainee**](docs/TraineeManagementApi.md#create_trainee) | **POST** /trainees | Create Trainee
*TraineeManagementApi* | [**delete_trainee**](docs/TraineeManagementApi.md#delete_trainee) | **DELETE** /trainee/{trainee_id} | Delete Trainee
*TraineeManagementApi* | [**destruct_trainee**](docs/TraineeManagementApi.md#destruct_trainee) | **POST** /internal/trainee/{trainee_id}/destruct | Teardown a trainee instance
*TraineeManagementApi* | [**get_trainee**](docs/TraineeManagementApi.md#get_trainee) | **GET** /trainee/{trainee_id} | Get Trainee
*TraineeManagementApi* | [**list_trainees**](docs/TraineeManagementApi.md#list_trainees) | **GET** /manage/trainees/ | List your trainees.
*TraineeManagementApi* | [**persist_trace**](docs/TraineeManagementApi.md#persist_trace) | **POST** /trainee/{trainee_id}/persist-trace | Persist trainee trace
*TraineeManagementApi* | [**persist_trainee**](docs/TraineeManagementApi.md#persist_trainee) | **POST** /trainee/{trainee_id}/persist | Persist trainee
*TraineeManagementApi* | [**release_trainee_resources**](docs/TraineeManagementApi.md#release_trainee_resources) | **POST** /trainee/{trainee_id}/resources/release | Release Trainee resources
*TraineeManagementApi* | [**resolve_trainee**](docs/TraineeManagementApi.md#resolve_trainee) | **GET** /manage/trainees/resolve/ |
*TraineeManagementApi* | [**self_destruct_trainee**](docs/TraineeManagementApi.md#self_destruct_trainee) | **PUT** /internal/trainee/{trainee_id}/destruct | Unexpectedly fail a trainee
*TraineeManagementApi* | [**set_random_seed**](docs/TraineeManagementApi.md#set_random_seed) | **POST** /trainee/{trainee_id}/random-seed | Set Trainee&#39;s random seed
*TraineeManagementApi* | [**set_trainee**](docs/TraineeManagementApi.md#set_trainee) | **PUT** /trainee/{trainee_id} | Set Trainee
*TraineeMetricsApi* | [**distances**](docs/TraineeMetricsApi.md#distances) | **POST** /trainee/{trainee_id}/metrics/distances | Computes distances matrix.
*TraineeMetricsApi* | [**pairwise_distances**](docs/TraineeMetricsApi.md#pairwise_distances) | **POST** /trainee/{trainee_id}/metrics/pairwise-distances | Computes pairwise distances for specified from and to cases or values.
*TraineeOperationsApi* | [**analyze**](docs/TraineeOperationsApi.md#analyze) | **POST** /trainee/{trainee_id}/analyze | Analyze the trainee
*TraineeOperationsApi* | [**append_to_series_store**](docs/TraineeOperationsApi.md#append_to_series_store) | **POST** /trainee/{trainee_id}/series/append | Append contexts to series store
*TraineeOperationsApi* | [**auto_analyze**](docs/TraineeOperationsApi.md#auto_analyze) | **POST** /trainee/{trainee_id}/analyze/auto | Automatically analyze the trainee
*TraineeOperationsApi* | [**evaluate**](docs/TraineeOperationsApi.md#evaluate) | **POST** /trainee/{trainee_id}/evaluate | Evaluate custom code on cases within a trainee
*TraineeOperationsApi* | [**get_feature_mda**](docs/TraineeOperationsApi.md#get_feature_mda) | **POST** /trainee/{trainee_id}/feature/mda | Get the feature mean decrease in accuracy.
*TraineeOperationsApi* | [**get_workflow_attributes**](docs/TraineeOperationsApi.md#get_workflow_attributes) | **GET** /trainee/{trainee_id}/attributes | Get trainee workflow attributes
*TraineeOperationsApi* | [**impute**](docs/TraineeOperationsApi.md#impute) | **POST** /trainee/{trainee_id}/impute | Impute
*TraineeOperationsApi* | [**react**](docs/TraineeOperationsApi.md#react) | **POST** /trainee/{trainee_id}/react | React to one or more contexts
*TraineeOperationsApi* | [**react_group**](docs/TraineeOperationsApi.md#react_group) | **POST** /trainee/{trainee_id}/react/group | React to a grouping of cases.
*TraineeOperationsApi* | [**react_into_features**](docs/TraineeOperationsApi.md#react_into_features) | **POST** /trainee/{trainee_id}/react/into-features | React into features
*TraineeOperationsApi* | [**react_into_trainee**](docs/TraineeOperationsApi.md#react_into_trainee) | **POST** /trainee/{trainee_id}/react/into-trainee | React into trainee
*TraineeOperationsApi* | [**react_series**](docs/TraineeOperationsApi.md#react_series) | **POST** /trainee/{trainee_id}/react/series | React to one or more contexts in series
*TraineeOperationsApi* | [**remove_series_store**](docs/TraineeOperationsApi.md#remove_series_store) | **POST** /trainee/{trainee_id}/series/remove | Clear stored series from trainee
*TraineeOperationsApi* | [**set_auto_analyze_params**](docs/TraineeOperationsApi.md#set_auto_analyze_params) | **PUT** /trainee/{trainee_id}/analyze/auto/params | Set trainee parameters for auto analysis
*TraineeOperationsApi* | [**set_workflow_attributes**](docs/TraineeOperationsApi.md#set_workflow_attributes) | **PUT** /trainee/{trainee_id}/attributes | Set the trainee workflow attributes
*TraineeOperationsApi* | [**train**](docs/TraineeOperationsApi.md#train) | **POST** /trainee/{trainee_id}/train | Train a model
*TraineeSessionManagementApi* | [**delete_trainee_session**](docs/TraineeSessionManagementApi.md#delete_trainee_session) | **DELETE** /trainee/{trainee_id}/session/{session_id} | Remove session from trainee
*TraineeSessionManagementApi* | [**get_trainee_session_indices**](docs/TraineeSessionManagementApi.md#get_trainee_session_indices) | **GET** /trainee/{trainee_id}/session/{session_id}/indices | Retrieves the session indices for the provided session.
*TraineeSessionManagementApi* | [**get_trainee_session_training_indices**](docs/TraineeSessionManagementApi.md#get_trainee_session_training_indices) | **GET** /trainee/{trainee_id}/session/{session_id}/training-indices | Retrieves the session training indices for the provided session.
*TraineeSessionManagementApi* | [**get_trainee_sessions**](docs/TraineeSessionManagementApi.md#get_trainee_sessions) | **GET** /trainee/{trainee_id}/sessions | Get all session IDs for a trainee
*TraineeStatusApi* | [**get_trainee_metrics**](docs/TraineeStatusApi.md#get_trainee_metrics) | **GET** /trainee/{trainee_id}/status/metrics | Get the metrics of the trainee


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountIdentity](docs/AccountIdentity.md)
 - [AnalyzeRequest](docs/AnalyzeRequest.md)
 - [AppendToSeriesStoreRequest](docs/AppendToSeriesStoreRequest.md)
 - [AsyncAction](docs/AsyncAction.md)
 - [AsyncActionAccepted](docs/AsyncActionAccepted.md)
 - [AsyncActionAcceptedTracking](docs/AsyncActionAcceptedTracking.md)
 - [AsyncActionCancel](docs/AsyncActionCancel.md)
 - [AsyncActionCancelledOutput](docs/AsyncActionCancelledOutput.md)
 - [AsyncActionCompleteOutput](docs/AsyncActionCompleteOutput.md)
 - [AsyncActionFailedOutput](docs/AsyncActionFailedOutput.md)
 - [AsyncActionOutput](docs/AsyncActionOutput.md)
 - [AsyncActionStatus](docs/AsyncActionStatus.md)
 - [BaseAsyncActionOutput](docs/BaseAsyncActionOutput.md)
 - [BaseReactRequest](docs/BaseReactRequest.md)
 - [BeginSessionRequest](docs/BeginSessionRequest.md)
 - [BooleanType](docs/BooleanType.md)
 - [CPULimits](docs/CPULimits.md)
 - [CaseCountResponse](docs/CaseCountResponse.md)
 - [CaseEditRequest](docs/CaseEditRequest.md)
 - [CaseRemoveRequest](docs/CaseRemoveRequest.md)
 - [Cases](docs/Cases.md)
 - [CasesRequest](docs/CasesRequest.md)
 - [CopyTraineeRequest](docs/CopyTraineeRequest.md)
 - [CreateTraineeActionAccepted](docs/CreateTraineeActionAccepted.md)
 - [DateType](docs/DateType.md)
 - [DatetimeType](docs/DatetimeType.md)
 - [DefaultFeatures](docs/DefaultFeatures.md)
 - [DestructTraineeResponse](docs/DestructTraineeResponse.md)
 - [DistancesRequest](docs/DistancesRequest.md)
 - [DistancesResponse](docs/DistancesResponse.md)
 - [HowsoPlatformVersion](docs/HowsoPlatformVersion.md)
 - [HowsoVersion](docs/HowsoVersion.md)
 - [Error](docs/Error.md)
 - [EvaluateActionOutput](docs/EvaluateActionOutput.md)
 - [EvaluateRequest](docs/EvaluateRequest.md)
 - [EvaluateResponse](docs/EvaluateResponse.md)
 - [ExtremeCasesRequest](docs/ExtremeCasesRequest.md)
 - [FeatureAddRequest](docs/FeatureAddRequest.md)
 - [FeatureAttributes](docs/FeatureAttributes.md)
 - [FeatureAutoDeriveOnTrain](docs/FeatureAutoDeriveOnTrain.md)
 - [FeatureAutoDeriveOnTrainCustom](docs/FeatureAutoDeriveOnTrainCustom.md)
 - [FeatureAutoDeriveOnTrainProgress](docs/FeatureAutoDeriveOnTrainProgress.md)
 - [FeatureBounds](docs/FeatureBounds.md)
 - [FeatureContributionsRequest](docs/FeatureContributionsRequest.md)
 - [FeatureConviction](docs/FeatureConviction.md)
 - [FeatureConvictionActionOutput](docs/FeatureConvictionActionOutput.md)
 - [FeatureConvictionRequest](docs/FeatureConvictionRequest.md)
 - [FeatureMarginalStats](docs/FeatureMarginalStats.md)
 - [FeatureMarginalStatsRequest](docs/FeatureMarginalStatsRequest.md)
 - [FeatureMdaRequest](docs/FeatureMdaRequest.md)
 - [FeatureOriginalType](docs/FeatureOriginalType.md)
 - [FeaturePredictionStats](docs/FeaturePredictionStats.md)
 - [FeaturePredictionStatsActionOutput](docs/FeaturePredictionStatsActionOutput.md)
 - [FeaturePredictionStatsRequest](docs/FeaturePredictionStatsRequest.md)
 - [FeatureRemoveRequest](docs/FeatureRemoveRequest.md)
 - [FeatureResidualsRequest](docs/FeatureResidualsRequest.md)
 - [FeatureTimeSeries](docs/FeatureTimeSeries.md)
 - [GenericActionOutput](docs/GenericActionOutput.md)
 - [ImputeRequest](docs/ImputeRequest.md)
 - [IntegerType](docs/IntegerType.md)
 - [MarginalStats](docs/MarginalStats.md)
 - [MemoryLimits](docs/MemoryLimits.md)
 - [Metrics](docs/Metrics.md)
 - [NumericType](docs/NumericType.md)
 - [ObjectType](docs/ObjectType.md)
 - [PairwiseDistancesActionOutput](docs/PairwiseDistancesActionOutput.md)
 - [PairwiseDistancesRequest](docs/PairwiseDistancesRequest.md)
 - [PredictionStats](docs/PredictionStats.md)
 - [Project](docs/Project.md)
 - [ProjectIdentity](docs/ProjectIdentity.md)
 - [RandomSeedRequest](docs/RandomSeedRequest.md)
 - [ReactActionOutput](docs/ReactActionOutput.md)
 - [ReactDetails](docs/ReactDetails.md)
 - [ReactGroupActionOutput](docs/ReactGroupActionOutput.md)
 - [ReactGroupRequest](docs/ReactGroupRequest.md)
 - [ReactGroupResponse](docs/ReactGroupResponse.md)
 - [ReactGroupResponseContent](docs/ReactGroupResponseContent.md)
 - [ReactIntoFeaturesActionOutput](docs/ReactIntoFeaturesActionOutput.md)
 - [ReactIntoFeaturesRequest](docs/ReactIntoFeaturesRequest.md)
 - [ReactIntoFeaturesResponse](docs/ReactIntoFeaturesResponse.md)
 - [ReactIntoTraineeActionOutput](docs/ReactIntoTraineeActionOutput.md)
 - [ReactIntoTraineeRequest](docs/ReactIntoTraineeRequest.md)
 - [ReactIntoTraineeResponse](docs/ReactIntoTraineeResponse.md)
 - [ReactRequest](docs/ReactRequest.md)
 - [ReactResponse](docs/ReactResponse.md)
 - [ReactResponseContent](docs/ReactResponseContent.md)
 - [ReactResponseContentDistanceRatioPartsInner](docs/ReactResponseContentDistanceRatioPartsInner.md)
 - [ReactResponseContentOutlyingFeatureValuesInnerValue](docs/ReactResponseContentOutlyingFeatureValuesInnerValue.md)
 - [ReactSeriesActionOutput](docs/ReactSeriesActionOutput.md)
 - [ReactSeriesRequest](docs/ReactSeriesRequest.md)
 - [ReactSeriesResponse](docs/ReactSeriesResponse.md)
 - [ReactSeriesResponseContent](docs/ReactSeriesResponseContent.md)
 - [RemoveSeriesStoreRequest](docs/RemoveSeriesStoreRequest.md)
 - [Session](docs/Session.md)
 - [SessionIdentity](docs/SessionIdentity.md)
 - [SetAutoAnalyzeParamsRequest](docs/SetAutoAnalyzeParamsRequest.md)
 - [StringType](docs/StringType.md)
 - [TimeType](docs/TimeType.md)
 - [TimedeltaType](docs/TimedeltaType.md)
 - [TraceResponse](docs/TraceResponse.md)
 - [TrainActionOutput](docs/TrainActionOutput.md)
 - [TrainRequest](docs/TrainRequest.md)
 - [TrainResponse](docs/TrainResponse.md)
 - [Trainee](docs/Trainee.md)
 - [TraineeAcquireResourcesRequest](docs/TraineeAcquireResourcesRequest.md)
 - [TraineeActionOutput](docs/TraineeActionOutput.md)
 - [TraineeCreateRequest](docs/TraineeCreateRequest.md)
 - [TraineeIdentity](docs/TraineeIdentity.md)
 - [TraineeInformation](docs/TraineeInformation.md)
 - [TraineeRequest](docs/TraineeRequest.md)
 - [TraineeResources](docs/TraineeResources.md)
 - [TraineeVersion](docs/TraineeVersion.md)
 - [TraineeWorkflowAttributes](docs/TraineeWorkflowAttributes.md)
 - [UpdateSessionRequest](docs/UpdateSessionRequest.md)
 - [Warning](docs/Warning.md)


## Documentation For Authorization


## oauth_ums

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**:
- **Scopes**:
 - **dp:trainee:read**: Trainee resource read scope
 - **dp:trainee:write**: Trainee resource write scope
 - **dp:trainee:execute**: Trainee resource execute scope
 - **dp:project:read**: Project resource read scope
 - **dp:project:write**: Project resource write scope
 - **dp:account:read**: Account resource read scope


## Author




